@@ -123,12 +123,12 @@ void ContactManager::stringToName(QString const& strname, ContactManager::Name&
 
     if(ename)
     {
-        QString additional = QString(ename->additional);
+        QString additional = QString::fromUtf8(ename->additional);
 
         if(additional.isEmpty())
         {
-            name.firstname = QString(ename->given);
-            name.surname = QString(ename->family);
+            name.firstname = QString::fromUtf8(ename->given);
+            name.surname = QString::fromUtf8(ename->family);
         }
         else
         {
